@@ -1,11 +1,11 @@
 #' @importFrom purrr walk
 run <- function(
   feature,
-  steps,
+  steps = get_steps(),
   parameters = get_parameters(),
   hooks = get_hooks()
 ) {
   tokens <- tokenize(feature)
   call_queue <- parse_token(tokens, steps, parameters, hooks)
-  walk(call_queue, eval)
+  walk(call_queue, \(x) x())
 }
