@@ -21,3 +21,18 @@ Given /^a directory without standard Cucumber project directory structure$/ do
     FileUtils.rm_rf 'features' if File.directory?('features')
   end
 end
+
+Given /^a scenario with a step that looks like this:$/ do |string|
+  create_feature do
+    create_scenario { string }
+  end
+end
+
+Given /^a step definition that looks like this:$/ do |string|
+  create_step_definition { string }
+end
+
+When /^I run the feature with the (\w+) formatter$/ do |formatter|
+  features.length.should == 1
+  run_feature features.first, formatter
+end
