@@ -51,7 +51,7 @@ module Cucumber
       include Enumerable
       include Gherkin::Rubify
       
-      NULL_CONVERSIONS = Hash.new(lambda{ |cell_value| cell_value }).freeze
+      NULL_CONVERSIONS = Hash.new({ :strict => false, :proc => lambda{ |cell_value| cell_value } }).freeze
 
       attr_accessor :file
 
@@ -71,7 +71,7 @@ module Cucumber
       # You don't typically create your own Table objects - Cucumber will do
       # it internally and pass them to your Step Definitions.
       #
-      def initialize(raw, conversion_procs = NULL_CONVERSIONS.dup)
+      def initialize(raw, conversion_procs = NULL_CONVERSIONS.dup, header_mappings = {}, header_conversion_proc = nil)
         @cells_class = Cells
         @cell_class = Cell
         raw = ensure_array_of_array(rubify(raw))
@@ -79,17 +79,19 @@ module Cucumber
         transposed = raw.transpose
         create_cell_matrix(raw)
         @conversion_procs = conversion_procs
+        @header_mappings = header_mappings
+        @header_conversion_proc = header_conversion_proc
       end
 
       def to_step_definition_arg
         dup
       end
 
-      # Creates a copy of this table, inheriting any column mappings.
-      # registered with #map_headers!
+      # Creates a copy of this table, inheriting any column and header mappings
+      # registered with #map_column! and #map_headers!.
       #
       def dup
-        self.class.new(raw.dup, @conversion_procs.dup)
+        self.class.new(raw.dup, @conversion_procs.dup, @header_mappings.dup, @header_conversion_proc)
       end
 
       # Returns a new, transposed table. Example:
@@ -104,9 +106,9 @@ module Cucumber
       #   | 4 | 2 |
       #
       def transpose
-        self.class.new(raw.transpose, @conversion_procs.dup)
+        self.class.new(raw.transpose, @conversion_procs.dup, @header_mappings.dup, @header_conversion_proc)
       end
-
+      
       # Converts this table into an Array of Hash where the keys of each
       # Hash are the headers in the table. For example, a Table built from
       # the following plain text:
@@ -122,9 +124,7 @@ module Cucumber
       # Use #map_column! to specify how values in a column are converted.
       #
       def hashes
-        @hashes ||= cells_rows[1..-1].map do |row|
-          row.to_hash
-        end
+        @hashes ||= build_hashes
       end
       
       # Converts this table into a Hash where the first column is
@@ -238,22 +238,8 @@ module Cucumber
       #   # => ['phone number', 'ADDRESS']
       #
       def map_headers!(mappings={}, &block)
-        header_cells = cell_matrix[0]
-
-        if block_given?
-          header_values = header_cells.map { |cell| cell.value } - mappings.keys
-          mappings = mappings.merge(Hash[*header_values.zip(header_values.map(&block)).flatten])
-        end
-
-        mappings.each_pair do |pre, post|
-          mapped_cells = header_cells.select{|cell| pre === cell.value}
-          raise "No headers matched #{pre.inspect}" if mapped_cells.empty?
-          raise "#{mapped_cells.length} headers matched #{pre.inspect}: #{mapped_cells.map{|c| c.value}.inspect}" if mapped_cells.length > 1
-          mapped_cells[0].value = post
-          if @conversion_procs.has_key?(pre)
-            @conversion_procs[post] = @conversion_procs.delete(pre)
-          end
-        end
+        @header_mappings = mappings
+        @header_conversion_proc = block
       end
 
       # Returns a new Table where the headers are redefined. See #map_headers!
@@ -276,8 +262,7 @@ module Cucumber
       #   end
       #
       def map_column!(column_name, strict=true, &conversion_proc)
-        verify_column(column_name.to_s) if strict
-        @conversion_procs[column_name.to_s] = conversion_proc
+        @conversion_procs[column_name.to_s] = { :strict => strict, :proc => conversion_proc }
         self
       end
 
@@ -300,7 +285,8 @@ module Cucumber
       # #diff!. You can use #map_column! on either of the tables.
       #
       # A Different error is raised if there are missing rows or columns, or
-      # surplus rows. An error is <em>not</em> raised for surplus columns.
+      # surplus rows. An error is <em>not</em> raised for surplus columns. An
+      # error is <em>not</em> raised for misplaced (out of sequence) columns.
       # Whether to raise or not raise can be changed by setting values in
       # +options+ to true or false:
       #
@@ -308,6 +294,7 @@ module Cucumber
       # * <tt>surplus_row</tt> : Raise on surplus rows (defaults to true)
       # * <tt>missing_col</tt> : Raise on missing columns (defaults to true)
       # * <tt>surplus_col</tt> : Raise on surplus columns (defaults to false)
+      # * <tt>misplaced_col</tt> : Raise on misplaced columns (defaults to false)
       #
       # The +other_table+ argument can be another Table, an Array of Array or
       # an Array of Hash (similar to the structure returned by #hashes).
@@ -316,11 +303,21 @@ module Cucumber
       # a Table argument, if you want to compare that table to some actual values. 
       #
       def diff!(other_table, options={})
-        options = {:missing_row => true, :surplus_row => true, :missing_col => true, :surplus_col => false}.merge(options)
+        options = {
+          :missing_row   => true,
+          :surplus_row   => true,
+          :missing_col   => true,
+          :surplus_col   => false,
+          :misplaced_col => false
+        }.merge(options)
 
         other_table = ensure_table(other_table)
+        other_table.convert_headers!
         other_table.convert_columns!
         ensure_green!
+                
+        convert_headers!
+        convert_columns!
 
         original_width = cell_matrix[0].length
         other_table_cell_matrix = pad!(other_table.cell_matrix)
@@ -328,10 +325,10 @@ module Cucumber
 
         missing_col = cell_matrix[0].detect{|cell| cell.status == :undefined}
         surplus_col = padded_width > original_width
+        misplaced_col = cell_matrix[0] != other_table.cell_matrix[0]
 
         require_diff_lcs
         cell_matrix.extend(Diff::LCS)
-        convert_columns!
         changes = cell_matrix.diff(other_table_cell_matrix).flatten
 
         inserted = 0
@@ -377,7 +374,8 @@ module Cucumber
           missing_row_pos && options[:missing_row] ||
           insert_row_pos  && options[:surplus_row] ||
           missing_col     && options[:missing_col] ||
-          surplus_col     && options[:surplus_col]
+          surplus_col     && options[:surplus_col] ||
+          misplaced_col   && options[:misplaced_col]
         raise Different.new(self) if should_raise
       end
 
@@ -386,8 +384,7 @@ module Cucumber
           hash[key.to_s] if key.is_a?(Symbol)
         end
         column_names.each_with_index do |column_name, column_index|
-          value = @conversion_procs[column_name].call(cells.value(column_index))
-          hash[column_name] = value
+          hash[column_name] = cells.value(column_index)
         end
         hash
       end
@@ -450,13 +447,13 @@ module Cucumber
         options = {:color => true, :indent => 2, :prefixes => TO_S_PREFIXES}.merge(options)
         io = StringIO.new
 
-        c = Term::ANSIColor.coloring?
-        Term::ANSIColor.coloring = options[:color]
+        c = Cucumber::Term::ANSIColor.coloring?
+        Cucumber::Term::ANSIColor.coloring = options[:color]
         formatter = Formatter::Pretty.new(nil, io, options)
         formatter.instance_variable_set('@indent', options[:indent])
         TreeWalker.new(nil, [formatter]).visit_multiline_arg(self)
         
-        Term::ANSIColor.coloring = c
+        Cucumber::Term::ANSIColor.coloring = c
         io.rewind
         s = "\n" + io.read + (" " * (options[:indent] - 2))
         s
@@ -470,6 +467,14 @@ module Cucumber
 
       protected
 
+      def build_hashes
+        convert_headers!
+        convert_columns!
+        cells_rows[1..-1].map do |row|
+          row.to_hash
+        end
+      end
+
       def inspect_rows(missing_row, inserted_row) #:nodoc:
         missing_row.each_with_index do |missing_cell, col|
           inserted_cell = inserted_row[col]
@@ -490,14 +495,38 @@ module Cucumber
       end
 
       def convert_columns! #:nodoc:
+        @conversion_procs.each do |column_name, conversion_proc|
+          verify_column(column_name) if conversion_proc[:strict]
+        end
+        
         cell_matrix.transpose.each do |col|
-          conversion_proc = @conversion_procs[col[0].value]
+          column_name = col[0].value
+          conversion_proc = @conversion_procs[column_name][:proc]
           col[1..-1].each do |cell|
             cell.value = conversion_proc.call(cell.value)
           end
         end
       end
 
+      def convert_headers! #:nodoc:
+        header_cells = cell_matrix[0]
+
+        if @header_conversion_proc
+          header_values = header_cells.map { |cell| cell.value } - @header_mappings.keys
+          @header_mappings = @header_mappings.merge(Hash[*header_values.zip(header_values.map(&@header_conversion_proc)).flatten])
+        end
+
+        @header_mappings.each_pair do |pre, post|
+          mapped_cells = header_cells.select { |cell| pre === cell.value }
+          raise "No headers matched #{pre.inspect}" if mapped_cells.empty?
+          raise "#{mapped_cells.length} headers matched #{pre.inspect}: #{mapped_cells.map { |c| c.value }.inspect}" if mapped_cells.length > 1
+          mapped_cells[0].value = post
+          if @conversion_procs.has_key?(pre)
+            @conversion_procs[post] = @conversion_procs.delete(pre)
+          end
+        end
+      end
+
       def require_diff_lcs #:nodoc:
         begin
           require 'diff/lcs'
