@@ -7,7 +7,7 @@ module Cucumber
         names = camel_cased_word.split('::')
         names.shift if names.empty? || names.first.empty?
 
-        constant = Object
+        constant = ::Object
         names.each do |name|
           constant = constant.const_defined?(name) ? constant.const_get(name) : constant.const_missing(name)
         end
