@@ -6,7 +6,7 @@ module Cucumber
     describe Progress do
 
       before(:each) do
-        Term::ANSIColor.coloring = false
+        Cucumber::Term::ANSIColor.coloring = false
         @out = StringIO.new
         progress = Cucumber::Formatter::Progress.new(mock("step mother"), @out, {})
         @visitor = Cucumber::Ast::TreeWalker.new(nil, [progress])
@@ -14,7 +14,7 @@ module Cucumber
  
       describe "visiting a table cell value without a status" do
         it "should take the status from the last run step" do
-          @visitor.visit_step_result('', '', nil, :failed, nil, 10, nil)
+          @visitor.visit_step_result('', '', nil, :failed, nil, 10, nil, nil)
           outline_table = mock()
           outline_table.should_receive(:accept) do |visitor|
             visitor.visit_table_cell_value('value', nil)
